/*
 * Copyright 2017-2024 original authors
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package example.micronaut

import io.micronaut.context.event.BeanCreatedEvent
import io.micronaut.context.event.BeanCreatedEventListener
import jakarta.inject.Singleton
import software.amazon.awssdk.auth.credentials.AwsBasicCredentials
import software.amazon.awssdk.auth.credentials.StaticCredentialsProvider
import software.amazon.awssdk.regions.Region
import software.amazon.awssdk.services.sqs.SqsClientBuilder
import java.net.URI
import java.net.URISyntaxException

@Singleton // <1>
class SqsClientBuilderListener(private val sqsConfig: SqsConfig) // <3>
    : BeanCreatedEventListener<SqsClientBuilder> { // <2>

    override fun onCreated(event: BeanCreatedEvent<SqsClientBuilder>): SqsClientBuilder {
        val builder = event.bean
        try {
            return builder
                .endpointOverride(URI(sqsConfig.sqs.endpointOverride!!))
                .credentialsProvider(
                    StaticCredentialsProvider.create(
                        AwsBasicCredentials.create(sqsConfig.accessKeyId, sqsConfig.secretKey)
                    )
                )
                .region(Region.of(sqsConfig.region))
        } catch (e: URISyntaxException) {
            throw RuntimeException(e)
        }
    }
}